Module epid_fast

Module epid_fast 

Structs

EpidFastDeviceSupport
Fast Epid device support using asyn driver for high-speed (1+ kHz) PID.
EpidFastPvt
Private state for the fast PID loop, shared between the record process thread and the interrupt callback task.