pub fn std_record_factories() -> Vec<(&'static str, RecordFactory)>Expand description
Return all std record type factories for bulk registration.
pub fn std_record_factories() -> Vec<(&'static str, RecordFactory)>Return all std record type factories for bulk registration.