pub fn timestamp_record_factory() -> (&'static str, RecordFactory)Expand description
Return the timestamp record type factory for injection into IocBuilder.
pub fn timestamp_record_factory() -> (&'static str, RecordFactory)Return the timestamp record type factory for injection into IocBuilder.