Delay-and-Do state machine — native Rust port of delayDo.st.
Implements a state machine that waits for a standby condition, monitors an active condition, and after the active condition clears (with a configurable delay), triggers an action.
State Machine
init ──► idle ◄──────────────────────────┐
│ ▲ │
│ └── maybeStandby ◄── disable │
▼ ▲ │
standby ──► maybeWait ──► waiting ──► action
▲ │ │
│ ▼ ▼
│ idle active ──► waiting
└──────────────────────┘Structs
- Delay
DoController - The delay-do controller.
- Delay
DoInputs - Input signals for the delay-do state machine.
Enums
- Delay
DoAction - Output actions from the delay-do state machine.
- Delay
DoState - States of the delay-do state machine.