Re-exports
pub use device_support::time_of_day::SecPastEpochDeviceSupport;pub use device_support::time_of_day::TimeOfDayStringDeviceSupport;pub use records::epid::EpidRecord;pub use records::throttle::ThrottleRecord;pub use records::timestamp::TimestampRecord;
Modules
Constants
- STD_
DB_ DIR - Path to the bundled database template directory.
Functions
- epid_
record_ factory - Return the epid record type factory for injection into IocBuilder.
- register_
std_ record_ types - Register all std record types via the global registry (legacy).
Prefer
std_record_factories()withIocBuilder::register_record_type(). - sec_
past_ epoch_ device_ factory - Return the “Sec Past Epoch” (
ai) device support factory fromdevTimeOfDay.c(devAiTodSeconds) for injection into a builder. - std_
device_ supports - Return all std-module device support factories for bulk registration.
- std_
record_ factories - Return all std record type factories for bulk registration.
- throttle_
record_ factory - Return the throttle record type factory for injection into IocBuilder.
- time_
of_ day_ device_ factory - Return the “Time of Day” (
stringin) device support factory fromdevTimeOfDay.c(devSiTodString) for injection into a builder. - timestamp_
record_ factory - Return the timestamp record type factory for injection into IocBuilder.