Re-exports
pub use records::epid::EpidRecord;pub use records::throttle::ThrottleRecord;pub use records::timestamp::TimestampRecord;
Modules
Constants
- STD_
DB_ DIR - Path to the bundled database template directory.
Functions
- epid_
record_ factory - Return the epid record type factory for injection into IocBuilder.
- register_
std_ record_ types - Register all std record types via the global registry (legacy).
Prefer
std_record_factories()withIocBuilder::register_record_type(). - std_
record_ factories - Return all std record type factories for bulk registration.
- throttle_
record_ factory - Return the throttle record type factory for injection into IocBuilder.
- timestamp_
record_ factory - Return the timestamp record type factory for injection into IocBuilder.