pub struct EpidFastDeviceSupport { /* private fields */ }Expand description
Fast Epid device support using asyn driver for high-speed (1+ kHz) PID.
Ported from devEpidFast.c. The PID computation runs in a background
tokio task driven by asyn interrupt callbacks, not during record
processing. The record merely copies parameters to/from the fast
computation thread.
Architecture
┌─────────────┐ interrupt ┌──────────────────┐
│ asyn driver │ ──────────────► │ PID callback task │
│ (input ADC) │ (new cval) │ (tokio::spawn) │
└─────────────┘ │ runs do_pid() │
│ writes output │
┌──────────────────────────┤ to output driver │
│ shared EpidFastPvt └──────────────────┘
│ (Arc<Mutex>) ▲
▼ │
┌─────────────┐ read() params │
│ EpidRecord │ ◄─────── copy ──────────┘
│ (process) │ ────────► copy ──────────►
└─────────────┘ resultsThe start_callback_loop() method spawns the background task.
Call it after connecting to the asyn input port.
Implementations
Sourceimpl EpidFastDeviceSupport
impl EpidFastDeviceSupport
pub fn new() -> Self
Sourcepub fn pvt(&self) -> Arc<Mutex<EpidFastPvt>>
pub fn pvt(&self) -> Arc<Mutex<EpidFastPvt>>
Get a handle to the shared PID state for callback registration.
Sourcepub fn start_callback_loop(
&self,
input_rx: Receiver<f64>,
output_fn: Arc<Mutex<dyn FnMut(f64) + Send>>,
)
pub fn start_callback_loop( &self, input_rx: Receiver<f64>, output_fn: Arc<Mutex<dyn FnMut(f64) + Send>>, )
Start the interrupt-driven PID callback loop.
Spawns a tokio task that receives new readback values from input_rx
and runs do_pid() on each. This is the high-speed PID path that
runs at the interrupt rate (1kHz+), independent of record processing.
input_rx: receives new controlled-variable values from the input driver
output_fn: called with each new output value (writes to output driver)
Sourcepub fn start_from_asyn_interrupts(
&self,
interrupt_rx: Receiver<InterruptValue>,
input_reason: usize,
output_fn: Arc<Mutex<dyn FnMut(f64) + Send>>,
)
pub fn start_from_asyn_interrupts( &self, interrupt_rx: Receiver<InterruptValue>, input_reason: usize, output_fn: Arc<Mutex<dyn FnMut(f64) + Send>>, )
Start from an asyn interrupt subscription.
Subscribes to Float64 interrupts from the given broadcast sender and feeds them into the PID callback loop.