EpidFastPvt

Struct EpidFastPvt 

pub struct EpidFastPvt {
Show 21 fields pub kp: f64, pub ki: f64, pub kd: f64, pub drvh: f64, pub drvl: f64, pub val: f64, pub fbon: bool, pub fmod: i16, pub cval: f64, pub oval: f64, pub err: f64, pub p: f64, pub i: f64, pub d: f64, pub dt: f64, pub ct: Instant, pub fbop: bool, pub num_average: u32, pub accumulated: f64, pub count: u32, pub output_writer: Option<Arc<Mutex<dyn FnMut(f64) + Send>>>,
}
Private state for the fast PID loop, shared between the record process thread and the interrupt callback task.

Fields

kp: f64ki: f64kd: f64drvh: f64drvl: f64val: f64fbon: boolfmod: i16cval: f64oval: f64err: f64p: f64i: f64d: f64dt: f64ct: Instantfbop: boolnum_average: u32accumulated: f64count: u32output_writer: Option<Arc<Mutex<dyn FnMut(f64) + Send>>>

Implementations

Source

impl EpidFastPvt

pub fn do_pid(&mut self, new_cval: f64)

Execute one PID cycle on new data. Called from the interrupt callback task. After computing the output, writes to the output port if configured.